==> 0.0.9.tar.gz: lib/widget/nui_miniprogram_webapp.dart <==
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:nui_miniprogram_web/jsengine/nui_miniprogram_web_jsengine.dart';
import 'package:nui_miniprogram_web/model/nui_miniprogram_webroute.dart';

class NUIMiniProgramWebApp extends StatefulWidget {
  NUIMiniProgramWebApp({@required this.initialRoute, this.routes, this.theme, this.background : Colors.white, this.builder});
  final NUIMiniProgramWebRoute initialRoute;
  final List<NUIMiniProgramWebRoute> routes;
  final TransitionBuilder builder;
  final Color background;
  final ThemeData theme;
  
  @override
  _NUIMiniProgramWebAppState createState() => _NUIMiniProgramWebAppState();
}

class _NUIMiniProgramWebAppState extends State<NUIMiniProgramWebApp> {
  NUIMiniProgramWebJSEngine jsEngine;

  @override
  void initState(){
    super.initState();
    jsEngine = NUIMiniProgramWebJSEngine.from(window)..initCrossEventListener((message) {
      print("Received message from channel: ${message.channel}, payload: ${message.data}");
      return null;
    });
    jsEngine.initInternalChannelsForWeb(context);
  }
  
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      builder: widget.builder ?? null,
      routes: _getRoutes(),
      theme: widget.theme,
      color: widget.background ?? Colors.white,
    );
  }

  Map<String, Widget Function(BuildContext)> _getRoutes(){
    final routeMap = Map<String, Widget Function(BuildContext)>();
    routeMap["/"] = (context) => widget.initialRoute.child(context);
    widget.routes?.forEach((element) {
      routeMap[element.route] = (context) => element.child(context);
    });
    return routeMap;
  }
}

==> 0.0.13.tar.gz: lib/widget/nui_miniprogram_webapp.dart <==
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:nui_miniprogram_web/jsengine/nui_miniprogram_web_jsengine.dart';
import 'package:nui_miniprogram_web/model/nui_miniprogram_webroute.dart';

class NUIMiniProgramWebApp extends StatefulWidget {
  NUIMiniProgramWebApp({@required this.initialRoute, this.routes, this.theme, this.background : Colors.white, this.builder});
  final NUIMiniProgramWebRoute initialRoute;
  final List<NUIMiniProgramWebRoute> routes;
  final TransitionBuilder builder;
  final Color background;
  final ThemeData theme;
  
  @override
  _NUIMiniProgramWebAppState createState() => _NUIMiniProgramWebAppState();
}

class _NUIMiniProgramWebAppState extends State<NUIMiniProgramWebApp> {
  NUIMiniProgramWebJSEngine jsEngine;

  @override
  void initState(){
    super.initState();
    jsEngine = NUIMiniProgramWebJSEngine.from(window)..initCrossEventListener((message) {
      return null;
    });
  }
  
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      builder: widget.builder ?? null,
      routes: _getRoutes(),
      theme: widget.theme,
      color: widget.background ?? Colors.white,
    );
  }

  Map<String, Widget Function(BuildContext)> _getRoutes(){
    final routeMap = Map<String, Widget Function(BuildContext)>();
    routeMap["/"] = (context) => Builder(
      builder: (context) {
        jsEngine.initInternalChannelsForWeb(context);
        return widget.initialRoute.child(context);
      },
    );
    widget.routes?.forEach((element) {
      routeMap[element.route] = (context) => element.child(context);
    });
    return routeMap;
  }
}
